@@ -11,10 +11,10 @@ test_that("plot_fretboard runs successfully", {
   expect_is(plot_fretboard(string = 6:1, fret = c(0, 2, 2, 0, 0, 0),
                            left_handed = TRUE), "ggplot")
   expect_is(plot_fretboard(string = 6:1, fret = c(0, 2, 2, 0, 0, 0), mute = 6,
-                           fret_range = 1:2),
+                           fret_range = c(0, 2)),
             "ggplot")
   expect_is(plot_fretboard(string = 6:1, fret = c(1, 2, 2, 1, 1, 1), mute = 6,
-                           fret_range = 1:2),
+                           fret_range = c(0, 3)),
             "ggplot")
   expect_is(
     plot_fretboard(6:1, c(0, 2, 2, 0, 0, 0), c("G", "U", "I", "T", "A", "R")),
@@ -81,23 +81,49 @@ test_that("plot_chord runs successfully", {
   idx <- c(1, 1, 2, 2, 2, 1)
   fill <- c("white", "black")[idx]
   lab_col <- c("black", "white")[idx]
+
   expect_is(
     plot_chord("xo221o", "notes", label_color = lab_col, point_fill = fill),
     "ggplot")
-  expect_is(plot_chord("355433", horizontal = TRUE, show_tuning = TRUE),
-            "ggplot")
-  expect_is(plot_chord("55433", horizontal = TRUE, show_tuning = TRUE),
-            "ggplot")
-  expect_is(plot_chord("55433", horizontal = TRUE, show_tuning = TRUE,
-                       fret_range = c(3, 6)),
-            "ggplot")
+  expect_is(
+    plot_chord("355433", horizontal = TRUE, show_tuning = TRUE),
+    "ggplot"
+  )
+  expect_is(
+    plot_chord("55433", horizontal = TRUE, show_tuning = TRUE),
+    "ggplot"
+  )
+  expect_is(
+    plot_chord("55433", horizontal = TRUE, show_tuning = TRUE, fret_range = c(2, 6)),
+    "ggplot"
+  )
   expect_is(plot_chord("0;2;3;1;"), "ggplot")
   expect_is(plot_chord("0 2 3 1"), "ggplot")
+  expect_is(plot_chord("o231", fret_labels = 3), "ggplot")
+  expect_is(plot_chord("10 12 13 11", show_tuning = TRUE), "ggplot")
+  expect_is(
+    plot_chord("o x 10 12 13 11", fret_range = c(9, 14), fret_labels = c(9, 12)),
+    "ggplot"
+  )
+
   expect_error(plot_chord(c("xo221o", "xo221o")),
                "Length of chord must be one.")
   expect_error(
     plot_chord("022300", tuning = "bass"),
-    "Cannot have more fret values than number of instrument strings.")
+    "Cannot have more fret values than number of instrument strings."
+  )
+  expect_error(
+    plot_chord("o x 10 12 13 11", fret_range = c(10, 14), fret_labels = c(9, 12)),
+    "Explicit fret range will cut off notes."
+  )
+  expect_error(
+    plot_chord("o o 10 12 13 11", fret_range = c(8, 14), fret_labels = c(9, 12)),
+    "Explicit fret range must be greater than implicit fret number of explicit open strings."
+  )
+  expect_error(
+    plot_chord("o o 10 12 13 11", fret_range = 9:14),
+    "Explicit fret range must be a vector of two numbers."
+  )
 
   unlink(file, recursive = TRUE, force = TRUE)
 })
